CameraLens enum

Which physical camera lens to use for a capture step.

Used by DiditConfig.defaultDocumentCamera and DiditConfig.defaultLivenessCamera. The native SDK falls back to whichever camera is available when the requested lens is not present on the device (for example a tablet with no front camera).

Inheritance
Available extensions

Values

front → const CameraLens
back → const CameraLens

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CameraLens>
A constant List of the values in this enum, in order of their declaration.