defaultDocumentCamera property

CameraLens? defaultDocumentCamera
final

Lens used when first entering the document capture screen. null keeps the native default (back camera). Falls back to the first available camera when the requested lens isn't present on the device.

Implementation

final CameraLens? defaultDocumentCamera;