showExitConfirmation property
Show a confirmation dialog when the user attempts to exit.
Default is true.
Implementation
final bool showExitConfirmation;
Show a confirmation dialog when the user attempts to exit.
Default is true.
final bool showExitConfirmation;