startVerificationWithWorkflow static method
Future<VerificationResult>
startVerificationWithWorkflow(
- String workflowId, {
- String? vendorData,
- DiditConfig? config,
Start identity verification by creating a new session with a workflow ID.
This creates a verification session on the Didit backend, then launches the native verification UI.
Example:
final result = await DiditSdk.startVerificationWithWorkflow(
'workflow-id',
vendorData: 'user-123',
config: DiditConfig(loggingEnabled: true),
);
Implementation
static Future<VerificationResult> startVerificationWithWorkflow(
String workflowId, {
String? vendorData,
DiditConfig? config,
}) async {
final raw = await SdkFlutterPlatform.instance.startVerificationWithWorkflow(
workflowId,
vendorData,
config?.toMap(),
);
return VerificationResult.fromMap(raw);
}