DiditTransactionActionRequired class

A user action required to complete the transaction.

Constructors

DiditTransactionActionRequired({required String type, String? url, String? sessionId, String? sessionToken, String? status, String? widgetSessionId, String? expiresAt})
const
DiditTransactionActionRequired.fromMap(Map<String, dynamic> map)
factory

Properties

expiresAt String?
Expiry timestamp of the wallet-ownership widget session.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
sessionToken String?
final
status String?
final
type String
Action type: typeVerificationSession or typeWalletOwnership.
final
url String?
Hosted URL to complete the action.
final
widgetSessionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited