DiditTransactionPayload class

A transaction to submit from the device.

Mirrors the Didit transaction wire contract (camelCase aliases).

Constructors

DiditTransactionPayload({required String txnId, String? txnDate, String? zoneId, String? type, DiditTransactionInfo? info, DiditTransactionParticipant? subject, DiditTransactionParticipant? counterparty, Map<String, dynamic>? props, DiditTravelRule? travelRule, bool? includeCryptoScreening})
const

Properties

counterparty DiditTransactionParticipant?
final
hashCode int
The hash code for this object.
no setterinherited
includeCryptoScreening bool?
final
info DiditTransactionInfo?
final
props Map<String, dynamic>?
Custom properties attached to the transaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject DiditTransactionParticipant?
final
travelRule DiditTravelRule?
final
txnDate String?
Transaction timestamp (ISO 8601).
final
txnId String
Your unique transaction identifier.
final
type String?
Transaction category, e.g. "crypto".
final
zoneId String?
Time zone identifier, e.g. "Europe/Madrid".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited