DiditTransactionPaymentMethod class
Payment method of a transaction participant.
Constructors
- DiditTransactionPaymentMethod({String? type, String? accountId, String? issuingCountry})
-
const
Properties
- accountId → String?
-
Account identifier, e.g. an IBAN, card fingerprint, or wallet address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuingCountry → String?
-
ISO 3166-1 alpha-2 issuing country.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited