DiditTransactionResult class

The result of a submitted or fetched transaction.

Constructors

DiditTransactionResult({required String transactionId, String? status, String? travelRuleStatus, DiditTransactionActionRequired? actionRequired})
const
DiditTransactionResult.fromMap(Map<String, dynamic> map)
factory

Properties

actionRequired DiditTransactionActionRequired?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
transactionId String
final
travelRuleStatus String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited