DiditTravelRule class

Travel rule information attached to a transaction.

Constructors

DiditTravelRule({String? status, String? protocol, bool? required, int? obligationsCount, Map<String, dynamic>? originatorData, Map<String, dynamic>? beneficiaryData, Map<String, dynamic>? metadata})
const

Properties

beneficiaryData Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
obligationsCount int?
final
originatorData Map<String, dynamic>?
final
protocol String?
final
required bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited