VerificationErrorType enum

Error type identifiers returned by the native SDK.

Inheritance
Available extensions

Values

sessionExpired → const VerificationErrorType
networkError → const VerificationErrorType
cameraAccessDenied → const VerificationErrorType
notInitialized → const VerificationErrorType
apiError → const VerificationErrorType
retryBlocked → const VerificationErrorType
unknown → const VerificationErrorType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String? value) VerificationErrorType

Constants

values → const List<VerificationErrorType>
A constant List of the values in this enum, in order of their declaration.