VerificationStatus enum
The status of a completed verification session.
Values
- approved → const VerificationStatus
-
The user's identity was successfully verified.
- pending → const VerificationStatus
-
The verification is still being reviewed.
- declined → const VerificationStatus
-
The verification was declined.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? value) → VerificationStatus
Constants
-
values
→ const List<
VerificationStatus> - A constant List of the values in this enum, in order of their declaration.