- Inheritance
-
- Object
- PlatformInterface
- SdkFlutterPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
startVerification(String token, Map<String, dynamic>? config)
→ Future<Map<String, dynamic>>
-
Start verification with an existing session token.
-
startVerificationWithWorkflow(String workflowId, String? vendorData, String? metadata, Map<String, dynamic>? contactDetails, Map<String, dynamic>? expectedDetails, Map<String, dynamic>? config)
→ Future<Map<String, dynamic>>
-
Start verification by creating a session with a workflow ID.
-
toString()
→ String
-
A string representation of this object.
inherited