DiditConfig class
Configuration options for the Didit verification SDK.
Constructors
- DiditConfig({String? languageCode, String? fontFamily, bool loggingEnabled = false})
-
const
Properties
- fontFamily → String?
-
Custom font family name to use throughout the SDK UI.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String?
-
ISO 639-1 language code for the SDK UI (e.g. "en", "fr", "ar").
final
- loggingEnabled → bool
-
Enable SDK debug logging.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited