DiditSdk class
Didit Identity Verification SDK for Flutter.
Provides two methods to start verification:
- startVerification — with an existing session token from your backend
- startVerificationWithWorkflow — with a workflow ID (SDK creates the session)
Constructors
- DiditSdk()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
startVerification(
String token, {DiditConfig? config}) → Future< VerificationResult> - Start identity verification with an existing session token.
-
startVerificationWithWorkflow(
String workflowId, {String? vendorData, DiditConfig? config}) → Future< VerificationResult> - Start identity verification by creating a new session with a workflow ID.