DiditTransactionInfo class
Monetary or crypto details of a transaction.
Constructors
Properties
- amount → double?
-
final
- amountInDefaultCurrency → double?
-
final
-
cryptoParams
→ Map<
String, dynamic> ? -
Crypto transfer parameters, e.g. {address, chain}.
final
- currency → String?
-
Currency code, e.g. "USD" or "ETH".
final
- currencyType → String?
-
Currency type, e.g. "fiat" or "crypto".
final
- defaultCurrencyCode → String?
-
final
- direction → String?
-
Transaction direction, e.g. "inbound" or "outbound".
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentDetails → String?
-
final
- paymentTxnId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited