DiditTransactionOptions class
Options for submitting or fetching a transaction.
Constructors
- DiditTransactionOptions({String? baseUrl, bool autoLaunchAction = true, void onTransactionUpdated(DiditTransactionResult result)?})
-
const
Properties
- autoLaunchAction → bool
-
Automatically launch a required wallet-ownership widget natively.
Default is
true. Averification_sessionaction is never auto-launched — it is always returned via DiditTransactionResult.actionRequired for the host app to launch with its own Didit verification integration.final - baseUrl → String?
-
Override the verification API base URL.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTransactionUpdated → void Function(DiditTransactionResult result)?
-
Called with the refreshed transaction after an auto-launched
wallet-ownership action completes and the transaction status has been
re-fetched.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited