DiditTransactionParticipant class
A transaction participant (subject or counterparty).
Constructors
Properties
-
address
→ Map<
String, dynamic> ? -
final
-
device
→ Map<
String, dynamic> ? -
final
- dob → String?
-
Date of birth (ISO 8601 date).
final
- externalUserId → String?
-
final
- firstName → String?
-
final
- fullName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
institutionInfo
→ Map<
String, dynamic> ? -
final
- lastName → String?
-
final
- paymentMethod → DiditTransactionPaymentMethod?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Participant type, e.g. "individual" or "company".
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited