VerificationError class

Describes an error that occurred during verification.

Constructors

VerificationError({required VerificationErrorType type, required String message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type VerificationErrorType
The category of error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited