MethodChannelSdkFlutter class
MethodChannel implementation of SdkFlutterPlatform.
- Inheritance
-
- Object
- PlatformInterface
- SdkFlutterPlatform
- MethodChannelSdkFlutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startVerification(
String token, Map< String, dynamic> ? config) → Future<Map< String, dynamic> > -
Start verification with an existing session token.
override
-
startVerificationWithWorkflow(
String workflowId, String? vendorData, String? metadata, Map< String, dynamic> ? contactDetails, Map<String, dynamic> ? expectedDetails, Map<String, dynamic> ? config) → Future<Map< String, dynamic> > -
Start verification by creating a session with a workflow ID.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited