MethodChannelSdkFlutter class
MethodChannel implementation of SdkFlutterPlatform.
- Inheritance
-
- Object
- PlatformInterface
- SdkFlutterPlatform
- MethodChannelSdkFlutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getTransaction(
String transactionToken, String transactionId, Map< String, dynamic> options) → Future<Map< String, dynamic> > -
Fetch a transaction previously submitted with the same token.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setTransactionUpdateHandler(
void handler(String callId, Map< String, dynamic> result)?) → void -
Register the handler invoked when the platform reports a refreshed
transaction after an auto-launched action completes.
override
-
startVerification(
String token, Map< String, dynamic> ? config) → Future<Map< String, dynamic> > -
Start verification with an existing session token.
override
-
startVerificationWithWorkflow(
String workflowId, String? vendorData, Map< String, dynamic> ? config) → Future<Map< String, dynamic> > -
Start verification by creating a session with a workflow ID.
override
-
submitTransaction(
String transactionToken, Map< String, dynamic> transaction, Map<String, dynamic> options) → Future<Map< String, dynamic> > -
Submit a transaction with a transaction SDK token.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited