- Inheritance
-
- Object
- PlatformInterface
- SdkFlutterPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getTransaction(String transactionToken, String transactionId, Map<String, dynamic> options)
→ Future<Map<String, dynamic>>
-
Fetch a transaction previously submitted with the same token.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setTransactionUpdateHandler(void handler(String callId, Map<String, dynamic> result)?)
→ void
-
Register the handler invoked when the platform reports a refreshed
transaction after an auto-launched action completes.
-
startVerification(String token, Map<String, dynamic>? config)
→ Future<Map<String, dynamic>>
-
Start verification with an existing session token.
-
startVerificationWithWorkflow(String workflowId, String? vendorData, Map<String, dynamic>? config)
→ Future<Map<String, dynamic>>
-
Start verification by creating a session with a workflow ID.
-
submitTransaction(String transactionToken, Map<String, dynamic> transaction, Map<String, dynamic> options)
→ Future<Map<String, dynamic>>
-
Submit a transaction with a transaction SDK token.
-
toString()
→ String
-
A string representation of this object.
inherited